import { ToolTip } from './tooltip';
export class ToggleToolTip extends ToolTip {
    constructor() {
        super(...arguments);
        this._clickHandler = () => {
            if (this._contentWrapper.style.display === 'none') {
                this.render();
                this._contentWrapper.style.display = 'block';
                this.setAttribute('open', '');
                return;
            }
            this._contentWrapper.style.display = 'none';
            this.removeAttribute('open');
        };
        this._closeOnOutsideClick = (e) => {
            const target = e.target;
            const isTarget = target === this._targetNode;
            const isChild = this.contains(target);
            if (!isChild && !isTarget) {
                this._contentWrapper.style.display = 'none';
                this.removeAttribute('open');
            }
        };
        this._closeOnEsc = (e) => {
            if (e.key === 'Escape') {
                this._contentWrapper.style.display = 'none';
                this.removeAttribute('open');
            }
        };
    }
    connectedCallback() {
        super.connectedCallback();
        this.innerHTML = this._generateMarkup(this.title, this.content);
        this._contentWrapper = this.querySelector('.o3-tooltip-wrapper');
        this._contentWrapper.style.display = 'none';
        this._targetNode = this.querySelector('.o3-toggletip-target');
        this._popperInstance = this.initialisePopper(this._targetNode, this._contentWrapper);
        this.render();
        this._addEventListeners();
    }
    disconnectedCallback() {
        super.disconnectedCallback();
        this._removeEventListeners();
    }
    _addEventListeners() {
        this._targetNode.addEventListener('click', this._clickHandler);
        // Close on outside click
        document.addEventListener('click', this._closeOnOutsideClick);
        // Remove toggletip on ESC
        this.addEventListener('keydown', this._closeOnEsc);
    }
    _removeEventListeners() {
        this._targetNode.removeEventListener('click', this._clickHandler);
        document.removeEventListener('click', this._closeOnOutsideClick);
        this.removeEventListener('keydown', this._closeOnEsc);
    }
    _generateMarkup(title, content) {
        // add type="button" to prevent form submission
        const tooltipButtonMarkup = `<button type="button" class="o3-toggletip-target"></button>`;
        return `
		${tooltipButtonMarkup}
		<div class="o3-tooltip-wrapper">
			<div data-tooltip-arrow></div>
			<div class="o3-tooltip-content" role="status">
				<div class="o3-tooltip-content-title">${title}</div>
				<div class="o3-tooltip-content-body">${content}</div>
			</div>
		</div>`;
    }
}
customElements.define('o3-tooltip-toggle', ToggleToolTip);
