import { createPopper } from '@popperjs/core';
export class ToolTip extends HTMLElement {
    constructor() {
        super();
    }
    static get observedAttributes() {
        return ['placement', 'title', 'content'];
    }
    get placement() {
        return this.getAttribute('placement');
    }
    set placement(value) {
        this.setAttribute('placement', value);
    }
    get title() {
        return this.getAttribute('title');
    }
    set title(value) {
        this.setAttribute('title', value);
    }
    get content() {
        return this.getAttribute('content');
    }
    set content(value) {
        this.setAttribute('content', value);
    }
    connectedCallback() {
        this.content = this.getAttribute('content');
        this.title = this.getAttribute('title');
        this.contentId = this.getAttribute('content-id');
    }
    attributeChangedCallback(name) {
        this.render(name);
    }
    disconnectedCallback() {
        this._popperInstance?.destroy();
    }
    render(name) {
        this._popperInstance?.setOptions({
            placement: this.placement,
        });
        if (name === 'title' || name === 'content') {
            const titleEl = this.querySelector('.o3-tooltip-content-title');
            const contentEl = this.querySelector('.o3-tooltip-content-body');
            if (titleEl) {
                titleEl.textContent = this.title;
            }
            if (contentEl) {
                contentEl.textContent = this.content;
            }
            if (!this.title) {
                this.setAttribute('no-title', '');
            }
            else {
                this.removeAttribute('no-title');
            }
        }
    }
    initialisePopper(targetNode, popperElement) {
        return createPopper(targetNode, popperElement, {
            placement: this.placement || 'top',
            modifiers: [
                {
                    name: 'preventOverflow',
                    options: {
                        rootBoundary: document.body,
                    },
                },
                {
                    name: 'eventListeners',
                    options: {
                        scroll: false,
                    },
                },
                {
                    name: 'flip',
                    options: {
                        fallbackPlacements: ['top', 'bottom', 'left', 'right'],
                        rootBoundary: document.body,
                    },
                },
                {
                    name: 'offset',
                    options: {
                        offset: [0, 16],
                    },
                },
            ],
        });
    }
}
